@@ -3,14 +3,15 @@ import numpy as np
 import pandas as pd
 
 from ..ecg import ecg_analyze
-from ..hrv import hrv_rsa
 from ..eda import eda_analyze
 from ..emg import emg_analyze
 from ..eog import eog_analyze
+from ..hrv import hrv_rsa
+from ..ppg import ppg_analyze
 from ..rsp import rsp_analyze
 
 
-def bio_analyze(data, sampling_rate=1000, method="auto"):
+def bio_analyze(data, sampling_rate=1000, method="auto", window_lengths='constant', subepoch_rate=[None, None]):
     """Automated analysis of bio signals.
 
     Wrapper for other bio analyze functions of
@@ -31,6 +32,16 @@ def bio_analyze(data, sampling_rate=1000, method="auto"):
         or 'interval-related' for analysis on longer periods of data. Defaults
         to 'auto' where the right method will be chosen based on the
         mean duration of the data ('event-related' for duration under 10s).
+    window_lengths : dict
+        Defaults to 'constant'. Add a dictionary of epoch start and end times for different
+        types of signals e.g., window_lengths = {'ECG': [0.5, 1.5], 'EDA': [0.5, 3.5]}
+    subepoch_rate : list, dict
+        For event-related analysis,, a smaller "sub-epoch" within the epoch of an event can be specified.
+        The ECG and RSP rate-related features of this "sub-epoch" (e.g., ECG_Rate, ECG_Rate_Max),
+        relative to the baseline (where applicable), will be computed, e.g., subepoch_rate = [1, 3]
+        or subepoch_rate = {'ECG_Rate' = [1, 2], 'RSP_Rate' = [1.5, None]} if different sub-epoch length
+        for different signal is desired. Defaults to [None, None]. The first value of the list specifies
+        the start of the sub-epoch and the second specifies the end of the sub-epoch (in seconds),
 
     Returns
     ----------
@@ -78,7 +89,7 @@ def bio_analyze(data, sampling_rate=1000, method="auto"):
     >>> data = nk.data("bio_resting_5min_100hz")
     >>>
     >>> # Process the data
-    >>> df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"], sampling_rate=100)
+    >>> df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"], ppg=data["PPG"], sampling_rate=100)
     >>>
     >>> # Analyze
     >>> nk.bio_analyze(df, sampling_rate=100) #doctest: +ELLIPSIS
@@ -96,6 +107,7 @@ def bio_analyze(data, sampling_rate=1000, method="auto"):
         rsp_cols = [col for col in data.columns if "RSP" in col]
         eda_cols = [col for col in data.columns if "EDA" in col]
         emg_cols = [col for col in data.columns if "EMG" in col]
+        ppg_cols = [col for col in data.columns if "PPG" in col]
         eog_cols = [col for col in data.columns if "EOG" in col]
         ecg_rate_col = [col for col in data.columns if "ECG_Rate" in col]
         rsp_phase_col = [col for col in data.columns if "RSP_Phase" in col]
@@ -105,6 +117,7 @@ def bio_analyze(data, sampling_rate=1000, method="auto"):
             rsp_cols = [col for col in data[i].columns if "RSP" in col]
             eda_cols = [col for col in data[i].columns if "EDA" in col]
             emg_cols = [col for col in data[i].columns if "EMG" in col]
+            ppg_cols = [col for col in data[i].columns if "PPG" in col]
             eog_cols = [col for col in data[i].columns if "EOG" in col]
             ecg_rate_col = [col for col in data[i].columns if "ECG_Rate" in col]
             rsp_phase_col = [col for col in data[i].columns if "RSP_Phase" in col]
@@ -114,30 +127,68 @@ def bio_analyze(data, sampling_rate=1000, method="auto"):
         )
 
     # ECG
-    ecg_data = data.copy()
     if len(ecg_cols) != 0:
-        ecg_analyzed = ecg_analyze(ecg_data, sampling_rate=sampling_rate, method=method)
+        ecg_data = data.copy()
+        if window_lengths != 'constant':
+            if 'ECG' in window_lengths.keys():  # only for epochs
+                ecg_data = _bio_analyze_slicewindow(ecg_data, window_lengths, signal='ECG')
+
+        ecg_analyzed = ecg_analyze(ecg_data, sampling_rate=sampling_rate, method=method, subepoch_rate=subepoch_rate)
         features = pd.concat([features, ecg_analyzed], axis=1, sort=False)
 
     # RSP
-    rsp_data = data.copy()
     if len(rsp_cols) != 0:
-        rsp_analyzed = rsp_analyze(rsp_data, sampling_rate=sampling_rate, method=method)
+        rsp_data = data.copy()
+
+        if window_lengths != 'constant':
+            if 'RSP' in window_lengths.keys():  # only for epochs
+                rsp_data = _bio_analyze_slicewindow(rsp_data, window_lengths, signal='RSP')
+
+        rsp_analyzed = rsp_analyze(rsp_data, sampling_rate=sampling_rate, method=method, subepoch_rate=subepoch_rate)
         features = pd.concat([features, rsp_analyzed], axis=1, sort=False)
 
     # EDA
     if len(eda_cols) != 0:
-        eda_analyzed = eda_analyze(data, sampling_rate=sampling_rate, method=method)
+        eda_data = data.copy()
+
+        if window_lengths != 'constant':
+            if 'EDA' in window_lengths.keys():  # only for epochs
+                eda_data = _bio_analyze_slicewindow(eda_data, window_lengths, signal='EDA')
+
+        eda_analyzed = eda_analyze(eda_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, eda_analyzed], axis=1, sort=False)
 
     # EMG
     if len(emg_cols) != 0:
-        emg_analyzed = emg_analyze(data, sampling_rate=sampling_rate, method=method)
+        emg_data = data.copy()
+
+        if window_lengths != 'constant':
+            if 'EMG' in window_lengths.keys():  # only for epochs
+                emg_data = _bio_analyze_slicewindow(emg_data, window_lengths, signal='EMG')
+
+        emg_analyzed = emg_analyze(emg_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, emg_analyzed], axis=1, sort=False)
 
+    # EMG
+    if len(ppg_cols) != 0:
+        ppg_data = data.copy()
+
+        if window_lengths != 'constant':
+            if 'PPG' in window_lengths.keys():  # only for epochs
+                ppg_data = _bio_analyze_slicewindow(ppg_data, window_lengths, signal='PPG')
+
+        ppg_analyzed = ppg_analyze(ppg_data, sampling_rate=sampling_rate, method=method)
+        features = pd.concat([features, ppg_analyzed], axis=1, sort=False)
+
     # EOG
     if len(eog_cols) != 0:
-        eog_analyzed = eog_analyze(data, sampling_rate=sampling_rate, method=method)
+        eog_data = data.copy()
+
+        if window_lengths != 'constant':
+            if 'EOG' in window_lengths.keys():  # only for epochs
+                eog_data = _bio_analyze_slicewindow(eog_data, window_lengths, signal='EOG')
+
+        eog_analyzed = eog_analyze(eog_data, sampling_rate=sampling_rate, method=method)
         features = pd.concat([features, eog_analyzed], axis=1, sort=False)
 
     # RSA
@@ -171,6 +222,20 @@ def bio_analyze(data, sampling_rate=1000, method="auto"):
 # =============================================================================
 # Internals
 # =============================================================================
+def _bio_analyze_slicewindow(data, window_lengths, signal='ECG'):
+
+    if signal in window_lengths.keys():
+        start = window_lengths[signal][0]
+        end = window_lengths[signal][1]
+        epochs = {}
+        for i, label in enumerate(data):
+            # Slice window
+            epoch = data[label].loc[(data[label].index > start) & (data[label].index < end)]
+            epochs[label] = epoch
+            epochs
+    return epochs
+
+
 def _bio_analyze_findduration(data, sampling_rate=1000):
     # If DataFrame
     if isinstance(data, pd.DataFrame):
