@@ -11,7 +11,7 @@ def complexity_r(signal, delay=None, dimension=None, method="maxApEn", show=Fals
     """Estimate optimal tolerance (similarity threshold)
     Parameters
     ----------
-    signal : list, array or Series
+    signal : Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
     delay : int
         Time delay (often denoted 'Tau', sometimes referred to as 'lag'). In practice, it is common to
