@@ -2,6 +2,6 @@
 
 from .data import data
 from .read_acqknowledge import read_acqknowledge
+from .read_bitalino import read_bitalino
 
-
-__all__ = ["read_acqknowledge", "data"]
+__all__ = ["read_acqknowledge", "read_bitalino", "data"]
