@@ -12,7 +12,7 @@ def ecg_segment(ecg_cleaned, rpeaks=None, sampling_rate=1000, show=False):
 
     Parameters
     ----------
-    ecg_cleaned : list, array or Series
+    ecg_cleaned : Union[list, np.array, pd.Series]
         The cleaned ECG channel as returned by `ecg_clean()`.
     rpeaks : dict
         The samples at which the R-peaks occur. Dict returned by
@@ -52,7 +52,9 @@ def ecg_segment(ecg_cleaned, rpeaks=None, sampling_rate=1000, show=False):
         _, rpeaks = ecg_peaks(ecg_cleaned, sampling_rate=sampling_rate, correct_artifacts=True)
         rpeaks = rpeaks["ECG_R_Peaks"]
 
-    epochs_start, epochs_end = _ecg_segment_window(rpeaks=rpeaks, sampling_rate=sampling_rate)
+    epochs_start, epochs_end = _ecg_segment_window(
+        rpeaks=rpeaks, sampling_rate=sampling_rate, desired_length=len(ecg_cleaned)
+    )
     heartbeats = epochs_create(
         ecg_cleaned, rpeaks, sampling_rate=sampling_rate, epochs_start=epochs_start, epochs_end=epochs_end
     )
@@ -63,7 +65,9 @@ def ecg_segment(ecg_cleaned, rpeaks=None, sampling_rate=1000, show=False):
         plt.plot(heartbeats_pivoted)
         plt.xlabel("Time (s)")
         plt.title("Individual Heart Beats")
-        cmap = iter(plt.cm.YlOrRd(np.linspace(0, 1, num=int(heartbeats_plot["Label"].nunique()))))
+        cmap = iter(
+            plt.cm.YlOrRd(np.linspace(0, 1, num=int(heartbeats_plot["Label"].nunique())))
+        )  # pylint: disable=no-member
         lines = []
         for x, color in zip(heartbeats_pivoted, cmap):
             (line,) = plt.plot(heartbeats_pivoted[x], color=color)
@@ -72,13 +76,13 @@ def ecg_segment(ecg_cleaned, rpeaks=None, sampling_rate=1000, show=False):
     return heartbeats
 
 
-def _ecg_segment_window(heart_rate=None, rpeaks=None, sampling_rate=1000):
+def _ecg_segment_window(heart_rate=None, rpeaks=None, sampling_rate=1000, desired_length=None):
 
     # Extract heart rate
     if heart_rate is not None:
         heart_rate = np.mean(heart_rate)
     if rpeaks is not None:
-        heart_rate = np.mean(signal_rate(rpeaks, sampling_rate=sampling_rate))
+        heart_rate = np.mean(signal_rate(rpeaks, sampling_rate=sampling_rate, desired_length=desired_length))
 
     # Modulator
     m = heart_rate / 60
