@@ -7,6 +7,7 @@ from ..stats import summary_plot
 from .hrv_frequency import _hrv_frequency_show, hrv_frequency
 from .hrv_nonlinear import _hrv_nonlinear_show, hrv_nonlinear
 from .hrv_time import hrv_time
+from .hrv_rsa import hrv_rsa
 from .hrv_utils import _hrv_get_rri, _hrv_sanitize_input
 
 
@@ -21,8 +22,9 @@ def hrv(peaks, sampling_rate=1000, show=False, **kwargs):
     Parameters
     ----------
     peaks : dict
-        Samples at which cardiac extrema (i.e., R-peaks, systolic peaks) occur. Dictionary returned
-        by ecg_findpeaks, ecg_peaks, ppg_findpeaks, or ppg_peaks.
+        Samples at which cardiac extrema (i.e., R-peaks, systolic peaks) occur.
+        Can be a list of indices or the output(s) of other functions such as ecg_peaks,
+        ppg_peaks, ecg_process or bio_process.
     sampling_rate : int, optional
         Sampling rate (Hz) of the continuous cardiac signal in which the peaks occur. Should be at
         least twice as high as the highest frequency in vhf. By default 1000.
@@ -37,11 +39,18 @@ def hrv(peaks, sampling_rate=1000, show=False, **kwargs):
         (see `hrv_frequency <https://neurokit2.readthedocs.io/en/latest/functions.html#neurokit2.hrv.hrv_frequency>`_)
         - time (see `hrv_time <https://neurokit2.readthedocs.io/en/latest/functions.html#neurokit2.hrv.hrv_time>`_)
         - non-linear
-        (see `hrv_nonlinear <https://neurokit2.readthedocs.io/en/latest/functions.html#neurokit2.hrv.hrv_nonlinear`_)
+        (see `hrv_nonlinear <https://neurokit2.readthedocs.io/en/latest/functions.html#neurokit2.hrv.hrv_nonlinear>`_)
+        If RSP data is provided (e.g., output of `bio_process`):
+        - rsa
+         Otherwise, to compute ECG-derived respiration,
+         use `hrv_rsa <https://neurokit2.readthedocs.io/en/latest/functions.html#neurokit2.hrv.hrv_rsa>`_
+         If no raw respiratory data is available, users can also choose to use
+         `ecg_rsp <https://neurokit2.readthedocs.io/en/latest/functions.html#neurokit2.ecg.ecg_rsp`_ to
+         obtain ECG-derived respiratory signal, although this is not an ideal procedure.
 
     See Also
     --------
-    ecg_peaks, ppg_peaks, hrv_time, hrv_frequency, hrv_nonlinear
+    ecg_peaks, ppg_peaks, hrv_time, hrv_frequency, hrv_nonlinear, hrv_rsa
 
     Examples
     --------
@@ -50,12 +59,19 @@ def hrv(peaks, sampling_rate=1000, show=False, **kwargs):
     >>> # Download data
     >>> data = nk.data("bio_resting_5min_100hz")
     >>>
-    >>> # Find peaks
-    >>> peaks, info = nk.ecg_peaks(data["ECG"], sampling_rate=100)
+    >>> # Clean signal and Find peaks
+    >>> ecg_cleaned = nk.ecg_clean(data["ECG"], sampling_rate=100)
+    >>> peaks, info = nk.ecg_peaks(ecg_cleaned, sampling_rate=100, correct_artifacts=True)
     >>>
     >>> # Compute HRV indices
     >>> hrv_indices = nk.hrv(peaks, sampling_rate=100, show=True)
     >>> hrv_indices #doctest: +SKIP
+    >>>
+    >>> # Compute HRV from processed signals
+    >>> signals, info = nk.bio_process(data, sampling_rate=100)
+    >>> hrv = nk.hrv(signals, sampling_rate=100, show=True)
+    >>> hrv #doctest: +SKIP
+
 
     References
     ----------
@@ -74,10 +90,20 @@ def hrv(peaks, sampling_rate=1000, show=False, **kwargs):
     out.append(hrv_frequency(peaks, sampling_rate=sampling_rate))
     out.append(hrv_nonlinear(peaks, sampling_rate=sampling_rate))
 
+    # Compute RSA if rsp data is available
+    if isinstance(peaks, pd.DataFrame):
+        rsp_cols = [col for col in peaks.columns if "RSP_Phase" in col]
+        if len(rsp_cols) == 2:
+            rsp_signals = peaks[rsp_cols]
+            rsa = hrv_rsa(peaks, rsp_signals, sampling_rate=sampling_rate)
+            out.append(pd.DataFrame([rsa]))
+
     out = pd.concat(out, axis=1)
 
     # Plot
     if show:
+        if isinstance(peaks, dict):
+            peaks = peaks["ECG_R_Peaks"]
         # Indices for plotting
         out_plot = out.copy(deep=False)
 
