@@ -3,16 +3,14 @@ from warnings import warn
 
 import numpy as np
 
-from ..epochs.eventrelated_utils import (
-    _eventrelated_addinfo,
-    _eventrelated_rate,
-    _eventrelated_sanitizeinput,
-    _eventrelated_sanitizeoutput,
-)
+from ..epochs.eventrelated_utils import (_eventrelated_addinfo,
+                                         _eventrelated_rate,
+                                         _eventrelated_sanitizeinput,
+                                         _eventrelated_sanitizeoutput)
 from ..misc import NeuroKitWarning
 
 
-def rsp_eventrelated(epochs, silent=False):
+def rsp_eventrelated(epochs, silent=False, subepoch_rate=[None, None]):
     """Performs event-related RSP analysis on epochs.
 
     Parameters
@@ -22,6 +20,12 @@ def rsp_eventrelated(epochs, silent=False):
         or a DataFrame containing all epochs, usually obtained via `epochs_to_df()`.
     silent : bool
         If True, silence possible warnings.
+    subepoch_rate : list
+        A smaller "sub-epoch" within the epoch of an event can be specified.
+        The ECG rate-related features of this "sub-epoch" (e.g., RSP_Rate, RSP_Rate_Max),
+        relative to the baseline (where applicable), will be computed. The first value of the list specifies
+        the start of the sub-epoch and the second specifies the end of the sub-epoch (in seconds),
+        e.g., subepoch_rate = [1, 3] or subepoch_rate = [1, None]. Defaults to [None, None].
 
     Returns
     -------
@@ -83,7 +87,7 @@ def rsp_eventrelated(epochs, silent=False):
         data[i] = {}  # Initialize empty container
 
         # Rate
-        data[i] = _eventrelated_rate(epochs[i], data[i], var="RSP_Rate")
+        data[i] = _eventrelated_rate(epochs[i], data[i], var="RSP_Rate", subepoch_rate=subepoch_rate)
 
         # Amplitude
         data[i] = _rsp_eventrelated_amplitude(epochs[i], data[i])
