@@ -5,13 +5,14 @@ import pandas as pd
 
 
 def rsp_plot(rsp_signals, sampling_rate=None):
-    """
-    Visualize respiration (RSP) data.
+    """Visualize respiration (RSP) data.
 
     Parameters
     ----------
     rsp_signals : DataFrame
         DataFrame obtained from `rsp_process()`.
+    sampling_rate : int
+        The desired sampling rate (in Hz, i.e., samples/second).
 
     Examples
     --------
@@ -22,6 +23,11 @@ def rsp_plot(rsp_signals, sampling_rate=None):
     >>> fig = nk.rsp_plot(rsp_signals)
     >>> fig #doctest: +SKIP
 
+    Returns
+    -------
+    fig
+        Figure representing a plot of the processed rsp signals.
+
     See Also
     --------
     rsp_process
