@@ -3,18 +3,30 @@ import numpy as np
 import pandas as pd
 
 
-def signal_formatpeaks(info, desired_length, peak_indices=None):
+def signal_formatpeaks(info, desired_length, peak_indices=None, other_indices=None):
     """Transforms an peak-info dict to a signal of given length."""
     if peak_indices is None:
         peak_indices = [key for key in info.keys() if "Peaks" in key]
 
     signals = {}
     for feature, values in info.items():
+        # Get indices of features
         if feature != "SCR_RecoveryTime" and any(x in str(feature) for x in ["Peak", "Onset", "Offset", "Trough", "Recovery"]):
             signals[feature] = _signal_from_indices(values, desired_length, 1)
             signals[feature] = signals[feature].astype('int64')  # indexing of feature using 1 and 0
+
+        # Get values of features
+        elif 'RecoveryTime' in feature:
+            # Sanitize indices and values
+            other_indices, values = _signal_sanitize_indices(other_indices, values)
+            # Append recovery time values to signal
+            signals[feature] = _signal_from_indices(other_indices, desired_length, values)
         else:
+            # Sanitize indices and values
+            peak_indices, values = _signal_sanitize_indices(peak_indices, values)
+            # Append peak values to signal
             signals[feature] = _signal_from_indices(peak_indices, desired_length, values)
+
     signals = pd.DataFrame(signals)
     return signals
 
@@ -22,6 +34,15 @@ def signal_formatpeaks(info, desired_length, peak_indices=None):
 # Internals
 # =============================================================================
 
+def _signal_sanitize_indices(indices, values):
+    # Check if nan in indices
+    if np.sum(np.isnan(indices)) > 0:
+        to_drop = np.argwhere(np.isnan(indices))[0]
+        for i in to_drop:
+            indices = np.delete(indices, i)
+            values = np.delete(values, i)
+
+    return indices, values
 
 def _signal_from_indices(indices, desired_length=None, value=1):
     """Generates array of 0 and given values at given indices.
@@ -29,7 +50,8 @@ def _signal_from_indices(indices, desired_length=None, value=1):
     Used in *_findpeaks to transform vectors of peak indices to signal.
 
     """
-    signal = np.zeros(desired_length, dtype=float)
+    # signal = np.zeros(desired_length, dtype=float)
+    signal = pd.Series(np.zeros(desired_length, dtype=float))
 
     if isinstance(indices, list) and (not indices):    # skip empty lists
         return signal
@@ -40,8 +62,13 @@ def _signal_from_indices(indices, desired_length=None, value=1):
     if isinstance(indices[0], float):
         indices = indices[~np.isnan(indices)].astype(int)
 
+    # Appending single value
     if isinstance(value, (int, float)):
         signal[indices] = value
+    # Appending multiple values
+    elif isinstance(value, (np.ndarray, list)):
+        for index, val in zip(indices, value):
+            signal.iloc[index] = val
     else:
         if len(value) != len(indices):
             raise ValueError(
@@ -49,6 +76,8 @@ def _signal_from_indices(indices, desired_length=None, value=1):
                 "is different from the number of indices."
             )
         signal[indices] = value
+        # signal[indices] = value
+
     return signal
 
 
