@@ -2,7 +2,7 @@
 import numpy as np
 
 
-def mad(x, constant=1.4826):
+def mad(x, constant=1.4826, **kwargs):
     """Median Absolute Deviation: a "robust" version of standard deviation.
 
     Parameters
@@ -28,7 +28,7 @@ def mad(x, constant=1.4826):
     - https://en.wikipedia.org/wiki/Median_absolute_deviation
 
     """
-    median = np.nanmedian(np.ma.array(x).compressed())
-    mad_value = np.nanmedian(np.abs(x - median))
+    median = np.nanmedian(np.ma.array(x).compressed(), **kwargs)
+    mad_value = np.nanmedian(np.abs(x - median), **kwargs)
     mad_value = mad_value * constant
     return mad_value
