@@ -3,6 +3,6 @@ import doctest
 import pytest
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     doctest.testmod()
     pytest.main()
